==> prestashop_1.5.0.5.zip: prestashop/install/langs/es/install.php <==
<?php return array (
  'informations' => 
  array (
  ),
  'translations' => 
  array (
    'menu_welcome' => '¡Bienvenido!',
    'menu_system' => 'Compatibilidad sistema',
    'menu_database' => 'Configuración de base de datos',
    'menu_configure' => 'Configuración de la tienda',
    'menu_process' => 'Instalación',
    'Choose the installer language:' => NULL,
    'Field required' => NULL,
    'Invalid shop name' => 'Nombre de la tienda no válido',
    'Your firstname contains some invalid characters' => 'Su nombre contiene caracteres no válidos',
    'Your lastname contains some invalid characters' => 'Su apellido contiene caracteres no válidos',
    'The password is incorrect (alphanumeric string with at least 8 characters)' => NULL,
    'Password and its confirmation are different' => NULL,
    'This e-mail address is invalid' => NULL,
    'The uploaded file exceeds the upload_max_filesize directive in php.ini' => 'El archivo enviado supera el tamaño máximo permitido.',
    'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form' => 'El archivo enviado supera el tamaño máximo permitido.',
    'The uploaded file was only partially uploaded' => 'El archivo fue parcialmente enviado.',
    'No file was uploaded' => NULL,
    'Missing a temporary folder' => 'Carece de la carpeta temporal para recibir su archivo de correo. ¡Por favor consulte su administrador de sistema!',
    'Failed to write file to disk' => 'No se pueden escribir archivos en el disco',
    'File upload stopped by extension' => 'Carga de archivos interrumpido a causa de la extensión incorrecta',
    'No error code available' => NULL,
    'This is not a valid image file' => NULL,
    'Image type is not supported' => NULL,
    'Image folder %s is not writable' => NULL,
    'Cannot upload the file' => NULL,
    'Lingerie and Adult' => NULL,
    'Animals and Pets' => 'Animales',
    'Art and Culture' => 'Cultura y ocio',
    'Babies' => 'Artículos para bebés',
    'Beauty and Personal Care' => 'Salud y belleza',
    'Cars' => 'Automóvil y motos',
    'Computer Hardware and Software' => 'Informática y programas',
    'Download' => 'Descargas',
    'Fashion and accessories' => 'Ropa y complementos',
    'Flowers, Gifts and Crafts' => 'Flores y regalos',
    'Food and beverage' => 'Alimentación y gastronomía',
    'HiFi, Photo and Video' => 'Hifi, foto y vídeo',
    'Home and Garden' => 'Casa y jardín',
    'Home Appliances' => 'Electrodomésticos',
    'Jewelry' => 'Joyería',
    'Mobile and Telecom' => 'Telefonía y comunicación',
    'Services' => 'Servicios',
    'Shoes and accessories' => 'Calzado y complementos',
    'Sports and Entertainment' => 'Deporte y ocio',
    'Travel' => 'Viajes y turismo',
    'Database is connected' => NULL,
    'A test e-mail has been sent to %s' => NULL,
    'An error occurred while sending email, please verify your parameters' => NULL,
    'Create settings.inc file' => NULL,
    'Create database tables' => NULL,
    'Populate database tables' => NULL,
    'Configure shop informations' => NULL,
    'Install modules' => NULL,
    'Install demonstration data' => NULL,
    'Install theme' => NULL,
    'PHP parameters:' => NULL,
    'Is PHP 5.1.2 or later installed ?' => NULL,
    'Can upload files ?' => NULL,
    'Can create new files and folders ?' => NULL,
    'Is GD Library installed ?' => NULL,
    'Is MySQL support is on ?' => NULL,
    'Write permissions on files:' => NULL,
    'Can open external URLs ?' => NULL,
    'Is PHP register global option off (recommended) ?' => NULL,
    'Is GZIP compression activated (recommended) ?' => NULL,
    'Is Mcrypt extension available (recommended) ?' => NULL,
    'Is PHP magic quotes option deactivated (recommended) ?' => NULL,
    'Is Dom extension loaded ?' => NULL,
    'Is PDO MySQL extension loaded ?' => NULL,
    'Shop settings and merchant account information' => 'Información sobre el vendedor',
    'Shop name:' => 'Nombre de la tienda:',
    'Main activity:' => 'Actividad principal',
    'Please choose your main activity' => NULL,
    'Other activity...' => 'Otra actividad...',
    'This information is not required, it will only be used for statistical purposes. This information does not change anything in your store.' => 'Esta información no es obligatoria, solo se utilizará para estadísticas. Proporcionarla o no, no cambiará nada en su tienda.',
    'Install demo products:' => NULL,
    'Yes' => 'Sí',
    'No' => 'No',
    'Demo products are a good way to learn how to use PrestaShop. You should install them if you are not familiar with it.' => NULL,
    'Default country:' => 'País por defecto:',
    'Select your country' => NULL,
    'Shop timezone:' => 'Zona horaria de la tienda:',
    'Select your timezone' => NULL,
    'Shop logo:' => 'Logo de la tienda:',
    'Recommended dimensions:' => 'Dimensiones recomendadas:',
    'First name:' => 'Nombre:',
    'Last name:' => 'Apellido:',
    'E-mail address:' => 'Dirección de email:',
    'Shop password:' => 'Contraseña de la tienda:',
    'Re-type to confirm:' => 'Confirmar la contraseña:',
    'Receive this information by e-mail' => 'Recibe estos datos por email',
    'Warning: You will recieve these informations only if your e-mail configuration is correct.' => NULL,
    'Configure your database by filling out the following fields:' => 'Configure su base de datos llenando los siguientes campos:',
    'You have to create a database, help available in <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>' => NULL,
    'You have to create a database, help available in <a href="README.txt" target="_blank">~/install/README.txt</a>' => NULL,
    'Database server address:' => NULL,
    'If you want to use a different port, add :XX after your server address where XX is your port number.' => NULL,
    'Database name:' => 'Nombre de la base de datos:',
    'Database login:' => 'Inicio de la base de datos',
    'Database password:' => 'Contraseña de la base de datos',
    'Database Engine:' => 'Tipo de base de datos:',
    'Tables prefix:' => 'Prefijo de las tablas:',
    'Drop existing tables (mode dev):' => NULL,
    'Verify now!' => NULL,
    'E-mail delivery set-up' => NULL,
    'Configure SMTP manually (advanced users only)' => 'Configurar el envío SMTP (expertos únicamente)',
    'By default, the PHP mail() function is used' => NULL,
    'SMTP server address:' => NULL,
    'Encryption:' => 'Encriptación:',
    'None' => 'Ninguno',
    'Port:' => 'Puerto:',
    'Login:' => 'Nombre de usuario:',
    'Password:' => 'Contraseña:',
    'enter@your.email' => 'introduzca@su.email',
    'Send me a test email!' => '¡Envíeme un email de prueba!',
    'Next' => 'Siguiente',
    'Back' => 'Anterior',
    'Official forum' => NULL,
    'Support' => NULL,
    'Documentation' => NULL,
    'Contact us!' => '¡Contacte con nosotros!',
    'Forum' => NULL,
    'Blog' => 'El blog',
    'Done!' => NULL,
    'An error occured during installation...' => NULL,
    'You can use the links on the left column to go back to the previous steps, or restart the installation process by <a href="%s">clicking here</a>' => NULL,
    'Your installation is finished!' => '¡La instalación está terminada!',
    'You have just finished to install and configure your shop, thank you for using PrestaShop!' => NULL,
    'Please remember your login information:' => NULL,
    'WARNING: For security purposes, you must delete the "install" folder.' => 'ATENCION : para más seguridad, por favor borre la carpeta \'/install\'.',
    'Back Office' => 'Back Office',
    'Manage your store using your Back Office. Manage your orders and customers, add modules, change themes, etc.' => 'Administre su tienda con su back office. Maneja sus pedidos y clientes, agregue módulos, cambie su tema, etc ...',
    'Manage your store' => 'Administre su tienda',
    'Front Office' => 'Front Office',
    'Discover your store as your future customers will see it!' => '¡Descubra su tienda tal como la verán sus clientes!',
    'Discover your store' => 'Descubra su tienda',
    'Required set-up. Please verify the following checklist items are true.' => NULL,
    'Your configuration is valid, click next to continue!' => NULL,
    'Your configuration is invalid. Please fix the issues below:' => 'Su configuración no es válida,<br />gracias por corregir la configuración:',
    'Optional set-up' => 'Parámetros opcionales',
    'Refresh these settings' => NULL,
    'Welcome to the PrestaShop %s Installer.' => NULL,
    'The installation process should take only few minutes!' => 'El proceso de instalación tardará solo unos minutos.',
    'If you need help, do not hesitate to check <a href="%1$s" target="_blank">our documentation</a> or to contact our support team: %2$s' => NULL,
    'Did you know?' => '¿Sabía que?',
    'PrestaShop and community offers over 40 different languages for free directly accessible from your back-office in tools tab' => NULL,
    'Licenses Agreement' => 'Contrato de Licencia',
    'PrestaShop core is released under the OSL 3.0 while PrestaShop modules and themes are released under the AFL 3.0.' => NULL,
    'I agree to the above terms and conditions.' => 'Estoy de acuerdo con los términos y condiciones.',
    'I agree to participate in improving the solution by sending anonymous information about my configuration.' => NULL,
    'If you have any questions, please visit our <a href="%1$s" target="_blank">documentation</a> and <a href="%2$s" target="_blank">community forum</a>.' => NULL,
	'Test message from PrestaShop' => 'Instalación Prestashop - Prueba del servidor de correo',
	  'This is a test message, your server is now available to send email' => 'Este es un mensaje de prueba, el servidor de correo funciona correctamente.',
	  '%s - Login information' => NULL,
	  'An SQL error occured for entity <i>%1$s</i>: <i>%2$s</i>' => NULL,
	  'Cannot create image "%1$s" for entity "%2$s"' => NULL,
	  'Cannot create image "%1$s" (bad permissions on folder "%2$s")' => NULL,
	  'Cannot create image "%s"' => NULL,
	  'SQL error on query <i>%s</i>' => NULL,
	  'Server name is not valid' => NULL,
	  'You must enter a database name' => NULL,
	  'You must enter a database login' => NULL,
	  'Tables prefix is invalid' => NULL,
	  'Wrong engine chosen for MySQL' => NULL,
	  'Cannot convert database data to utf-8' => NULL,
	  'At least one table with same prefix was already found, please change your prefix or drop your database' => NULL,
	  'Database Server is not found. Please verify the login, password and server fields' => NULL,
	  'Connection to MySQL server succeeded, but database "%s" not found' => NULL,
	  'Engine innoDB is not supported by your MySQL server, please use MyISAM' => NULL,
	  '%s file is not writable (check permissions)' => NULL,
	  '%s folder is not writable (check permissions)' => NULL,
	  'Cannot write settings file' => NULL,
	  'Database structure file not found' => NULL,
	  'Cannot create group shop' => NULL,
	  'Cannot create shop' => NULL,
	  'Cannot create shop URL' => NULL,
	  'File "language.xml" not found for language iso "%s"' => NULL,
	  'File "language.xml" not valid for language iso "%s"' => NULL,
	  'Cannot install language "%s"' => NULL,
	  'Cannot create admin account' => NULL,
	  'Cannot install module "%s"' => NULL,
	  'Fixtures class "%s" not found' => NULL,
	  '"%s" must be an instane of "InstallXmlLoader"' => NULL,
  ),
);

==> prestashop_1.5.0.9.zip: prestashop/install/langs/es/install.php <==
<?php return array (
  'informations' => 
  array (
  ),
  'translations' => 
  array (
    'menu_welcome' => '¡Bienvenido!',
    'menu_system' => 'Compatibilidad sistema',
    'menu_database' => 'Configuración de base de datos',
    'menu_configure' => 'Configuración de la tienda',
    'menu_process' => 'Instalación',
    'Choose the installer language:' => NULL,
    'Field required' => NULL,
    'Invalid shop name' => 'Nombre de la tienda no válido',
    'Your firstname contains some invalid characters' => 'Su nombre contiene caracteres no válidos',
    'Your lastname contains some invalid characters' => 'Su apellido contiene caracteres no válidos',
    'The password is incorrect (alphanumeric string with at least 8 characters)' => NULL,
    'Password and its confirmation are different' => NULL,
    'This e-mail address is invalid' => NULL,
    'The uploaded file exceeds the upload_max_filesize directive in php.ini' => 'El archivo enviado supera el tamaño máximo permitido.',
    'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form' => 'El archivo enviado supera el tamaño máximo permitido.',
    'The uploaded file was only partially uploaded' => 'El archivo fue parcialmente enviado.',
    'No file was uploaded' => NULL,
    'Missing a temporary folder' => 'Carece de la carpeta temporal para recibir su archivo de correo. ¡Por favor consulte su administrador de sistema!',
    'Failed to write file to disk' => 'No se pueden escribir archivos en el disco',
    'File upload stopped by extension' => 'Carga de archivos interrumpido a causa de la extensión incorrecta',
    'No error code available' => NULL,
    'This is not a valid image file' => NULL,
    'Image type is not supported' => NULL,
    'Image folder %s is not writable' => NULL,
    'Cannot upload the file' => NULL,
    'Lingerie and Adult' => NULL,
    'Animals and Pets' => 'Animales',
    'Art and Culture' => 'Cultura y ocio',
    'Babies' => 'Artículos para bebés',
    'Beauty and Personal Care' => 'Salud y belleza',
    'Cars' => 'Automóvil y motos',
    'Computer Hardware and Software' => 'Informática y programas',
    'Download' => 'Descargas',
    'Fashion and accessories' => 'Ropa y complementos',
    'Flowers, Gifts and Crafts' => 'Flores y regalos',
    'Food and beverage' => 'Alimentación y gastronomía',
    'HiFi, Photo and Video' => 'Hifi, foto y vídeo',
    'Home and Garden' => 'Casa y jardín',
    'Home Appliances' => 'Electrodomésticos',
    'Jewelry' => 'Joyería',
    'Mobile and Telecom' => 'Telefonía y comunicación',
    'Services' => 'Servicios',
    'Shoes and accessories' => 'Calzado y complementos',
    'Sports and Entertainment' => 'Deporte y ocio',
    'Travel' => 'Viajes y turismo',
    'Database is connected' => NULL,
    'A test e-mail has been sent to %s' => NULL,
    'An error occurred while sending email, please verify your parameters' => NULL,
    'Create settings.inc file' => NULL,
    'Create database tables' => NULL,
    'Populate database tables' => NULL,
    'Configure shop information' => NULL,
    'Install modules' => NULL,
    'Install demonstration data' => NULL,
    'Install theme' => NULL,
    'PHP parameters:' => NULL,
    'Is PHP 5.1.2 or later installed ?' => NULL,
    'Can upload files ?' => NULL,
    'Can create new files and folders ?' => NULL,
    'Is GD Library installed ?' => NULL,
    'Is MySQL support is on ?' => NULL,
    'Write permissions on files:' => NULL,
    'Can open external URLs ?' => NULL,
    'Is PHP register global option off (recommended) ?' => NULL,
    'Is GZIP compression activated (recommended) ?' => NULL,
    'Is Mcrypt extension available (recommended) ?' => NULL,
    'Is PHP magic quotes option deactivated (recommended) ?' => NULL,
    'Is Dom extension loaded ?' => NULL,
    'Is PDO MySQL extension loaded ?' => NULL,
    'Shop settings and merchant account information' => 'Información sobre el vendedor',
    'Shop name:' => 'Nombre de la tienda:',
    'Main activity:' => 'Actividad principal',
    'Please choose your main activity' => NULL,
    'Other activity...' => 'Otra actividad...',
    'This information is not required, it will only be used for statistical purposes. This information does not change anything in your store.' => 'Esta información no es obligatoria, solo se utilizará para estadísticas. Proporcionarla o no, no cambiará nada en su tienda.',
    'Install demo products:' => NULL,
    'Yes' => 'Sí',
    'No' => 'No',
    'Demo products are a good way to learn how to use PrestaShop. You should install them if you are not familiar with it.' => NULL,
    'Default country:' => 'País por defecto:',
    'Select your country' => NULL,
    'Shop timezone:' => 'Zona horaria de la tienda:',
    'Select your timezone' => NULL,
    'Shop logo:' => 'Logo de la tienda:',
    'Recommended dimensions:' => 'Dimensiones recomendadas:',
    'First name:' => 'Nombre:',
    'Last name:' => 'Apellido:',
    'E-mail address:' => 'Dirección de email:',
    'Shop password:' => 'Contraseña de la tienda:',
    'Re-type to confirm:' => 'Confirmar la contraseña:',
    'Receive this information by e-mail' => 'Recibe estos datos por email',
    'Warning: You will recieve these informations only if your e-mail configuration is correct.' => NULL,
    'Configure your database by filling out the following fields:' => 'Configure su base de datos llenando los siguientes campos:',
    'You have to create a database, help available in <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>' => NULL,
    'You have to create a database, help available in <a href="README.txt" target="_blank">~/install/README.txt</a>' => NULL,
    'Database server address:' => NULL,
    'If you want to use a different port, add :XX after your server address where XX is your port number.' => NULL,
    'Database name:' => 'Nombre de la base de datos:',
    'Database login:' => 'Inicio de la base de datos',
    'Database password:' => 'Contraseña de la base de datos',
    'Database Engine:' => 'Tipo de base de datos:',
    'Tables prefix:' => 'Prefijo de las tablas:',
    'Drop existing tables (mode dev):' => NULL,
    'Verify now!' => NULL,
    'E-mail delivery set-up' => NULL,
    'Configure SMTP manually (advanced users only)' => 'Configurar el envío SMTP (expertos únicamente)',
    'By default, the PHP mail() function is used' => NULL,
    'SMTP server address:' => NULL,
    'Encryption:' => 'Encriptación:',
    'None' => 'Ninguno',
    'Port:' => 'Puerto:',
    'Login:' => 'Nombre de usuario:',
    'Password:' => 'Contraseña:',
    'enter@your.email' => 'introduzca@su.email',
    'Send me a test email!' => '¡Envíeme un email de prueba!',
    'Next' => 'Siguiente',
    'Back' => 'Anterior',
    'Official forum' => NULL,
    'Support' => NULL,
    'Documentation' => NULL,
    'Contact us!' => '¡Contacte con nosotros!',
    'Forum' => NULL,
    'Blog' => 'El blog',
    'Done!' => NULL,
    'An error occured during installation...' => NULL,
    'You can use the links on the left column to go back to the previous steps, or restart the installation process by <a href="%s">clicking here</a>.' => NULL,
    'Your installation is finished!' => '¡La instalación está terminada!',
    'You have just finished to install and configure your shop, thank you for using PrestaShop!' => NULL,
    'Please remember your login information:' => NULL,
    'WARNING: For security purposes, you must delete the "install" folder.' => 'ATENCION : para más seguridad, por favor borre la carpeta \'/install\'.',
    'Back Office' => 'Back Office',
    'Manage your store using your Back Office. Manage your orders and customers, add modules, change themes, etc.' => 'Administre su tienda con su back office. Maneja sus pedidos y clientes, agregue módulos, cambie su tema, etc ...',
    'Manage your store' => 'Administre su tienda',
    'Front Office' => 'Front Office',
    'Discover your store as your future customers will see it!' => '¡Descubra su tienda tal como la verán sus clientes!',
    'Discover your store' => 'Descubra su tienda',
    'Required set-up. Please verify the following checklist items are true.' => NULL,
    'Your configuration is valid, click next to continue!' => NULL,
    'Your configuration is invalid. Please fix the issues below:' => 'Su configuración no es válida,<br />gracias por corregir la configuración:',
    'Optional set-up' => 'Parámetros opcionales',
    'Refresh these settings' => NULL,
    'Welcome to the PrestaShop %s Installer.' => NULL,
    'The installation process should take only few minutes!' => 'El proceso de instalación tardará solo unos minutos.',
    'If you need help, do not hesitate to check <a href="%1$s" target="_blank">our documentation</a> or to contact our support team: %2$s' => NULL,
    'Did you know?' => '¿Sabía que?',
    'PrestaShop and community offers over 40 different languages for free directly accessible from your back-office in tools tab' => NULL,
    'Licenses Agreement' => 'Contrato de Licencia',
    'PrestaShop core is released under the OSL 3.0 while PrestaShop modules and themes are released under the AFL 3.0.' => NULL,
    'I agree to the above terms and conditions.' => 'Estoy de acuerdo con los términos y condiciones.',
    'I agree to participate in improving the solution by sending anonymous information about my configuration.' => NULL,
    'If you have any questions, please visit our <a href="%1$s" target="_blank">documentation</a> and <a href="%2$s" target="_blank">community forum</a>.' => NULL,
	'Test message from PrestaShop' => 'Instalación Prestashop - Prueba del servidor de correo',
	  'This is a test message, your server is now available to send email' => 'Este es un mensaje de prueba, el servidor de correo funciona correctamente.',
	  '%s - Login information' => NULL,
	  'An SQL error occured for entity <i>%1$s</i>: <i>%2$s</i>' => NULL,
	  'Cannot create image "%1$s" for entity "%2$s"' => NULL,
	  'Cannot create image "%1$s" (bad permissions on folder "%2$s")' => NULL,
	  'Cannot create image "%s"' => NULL,
	  'SQL error on query <i>%s</i>' => NULL,
	  'Server name is not valid' => NULL,
	  'You must enter a database name' => NULL,
	  'You must enter a database login' => NULL,
	  'Tables prefix is invalid' => NULL,
	  'Wrong engine chosen for MySQL' => NULL,
	  'Cannot convert database data to utf-8' => NULL,
	  'At least one table with same prefix was already found, please change your prefix or drop your database' => NULL,
	  'Database Server is not found. Please verify the login, password and server fields' => NULL,
	  'Connection to MySQL server succeeded, but database "%s" not found' => NULL,
	  'Engine innoDB is not supported by your MySQL server, please use MyISAM' => NULL,
	  '%s file is not writable (check permissions)' => NULL,
	  '%s folder is not writable (check permissions)' => NULL,
	  'Cannot write settings file' => NULL,
	  'Database structure file not found' => NULL,
	  'Cannot create group shop' => NULL,
	  'Cannot create shop' => NULL,
	  'Cannot create shop URL' => NULL,
	  'File "language.xml" not found for language iso "%s"' => NULL,
	  'File "language.xml" not valid for language iso "%s"' => NULL,
	  'Cannot install language "%s"' => NULL,
	  'Cannot create admin account' => NULL,
	  'Cannot install module "%s"' => NULL,
	  'Fixtures class "%s" not found' => NULL,
	  '"%s" must be an instane of "InstallXmlLoader"' => NULL,
  ),
);
